@@ -12,7 +12,7 @@ async def test_probe_async():
     # doesn't happen anymore.
     def gen():
         for _ in range(10_000):
-            yield Probe("127.0.0.1", 24000, 33434, 32, "icmp")
+            yield Probe("127.0.0.1", 24000, 33434, 32, "icmp", 0)
 
     logging.basicConfig(level=logging.DEBUG)
     set_log_level(logging.DEBUG)
